a.pdm-expansions {
  cursor: pointer;
  font-weight: bold;
  color: currentColor;
}

.bot-container {
  z-index: 9;
  position: fixed;
  width: 400px;
  right: 20px;
  bottom: 110px;
  display: flex;
  flex-direction: column;
  align-items:end;
}

.bot-container > iframe {
  width:100%;
  border:none;
  border-radius:0.5rem;
  transition: height 0.3s ease-in-out;
  height: 0;
}
.bot-button {
  padding: 0.8rem;
  border-radius: 50%;
  width: 80px;
  height: 80px;
  background-color: var(--md-primary-fg-color);
  transition: all 0.2s ease-in-out;
  fill: white;
}

.bot-button:hover {
  transform: translateY(-3px);
  padding: 0.7rem;
}

/* for readthedocs badge */
#readthedocs-embed-flyout {
  position: sticky;
  bottom: 0px;
  width: auto;
  max-width: 200px;
}
